@@ -64,7 +64,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::Plugin::Manifest::Write
 # ABSTRACT: Have annotated distribution manifest
-our $VERSION = 'v0.9.3'; # VERSION
+our $VERSION = 'v0.9.4'; # VERSION
 
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -288,7 +288,7 @@ sub _is_injector {
 #pod
 #pod C<Int>, read-only. Default is 1.
 #pod
-#pod See L<Dist::Zilla::Plugin::Manifets::Write::Manual/"strict">.
+#pod See L<Dist::Zilla::Plugin::Manifest::Write::Manual/"strict">.
 #pod
 #pod =cut
 
@@ -865,7 +865,7 @@ Dist::Zilla::Plugin::Manifest::Write - Have annotated distribution manifest
 
 =head1 VERSION
 
-Version v0.9.3, released on 2015-10-07 08:03 UTC.
+Version v0.9.4, released on 2015-10-12 23:30 UTC.
 
 =head1 WHAT?
 
@@ -959,7 +959,7 @@ fatal, some are not), or 1 (all mistakes are fatal).
 
 C<Int>, read-only. Default is 1.
 
-See L<Dist::Zilla::Plugin::Manifets::Write::Manual/"strict">.
+See L<Dist::Zilla::Plugin::Manifest::Write::Manual/"strict">.
 
 =head2 show_mungers
 
